hyperspy\.tests\.drawing package
================================

Submodules
----------

hyperspy\.tests\.drawing\.test\_figure\_title module
----------------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_figure_title
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.drawing\.test\_mpl\_testing\_setup module
----------------------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_mpl_testing_setup
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.drawing\.test\_plot\_markers module
----------------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_plot_markers
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.drawing\.test\_plot\_mva module
------------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_plot_mva
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.drawing\.test\_plot\_signal module
---------------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_plot_signal
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.drawing\.test\_plot\_signal1d module
-----------------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_plot_signal1d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.drawing\.test\_plot\_signal2d module
-----------------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_plot_signal2d
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.drawing\.test\_utils module
--------------------------------------------

.. automodule:: hyperspy.tests.drawing.test_utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.tests.drawing
    :members:
    :undoc-members:
    :show-inheritance:
